OC.L10N.register(
    "mail",
    {
    "Mail" : "ಅಂಚೆ",
    "Name" : "﻿ಹೆಸರು",
    "Password" : "ಗುಪ್ತ ಪದ",
    "None" : "﻿ಯಾವುದೂ ಇಲ್ಲ",
    "SMTP Password" : "﻿SMTP ಗುಪ್ತ ಪದ",
    "Save" : "﻿ಉಳಿಸಿ",
    "Send" : "﻿ಕಳುಹಿಸಿ",
    "Select" : "Select",
    "Move" : "Move",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Choose" : "﻿ಆಯ್ಕೆ",
    "Favorites" : "ಅಚ್ಚುಮೆಚ್ಚಿನ",
    "Other" : "﻿ಇತರೆ",
    "Settings" : "ಆಯ್ಕೆ",
    "Quota" : "ಪಾಲು",
    "Add folder" : "Add folder",
    "Cancel" : "﻿ರದ್ದು",
    "User" : "User",
    "Host" : "ಅತಿಥೆಯ-ಗಣಕ",
    "Port" : "﻿ರೇವು",
    "Search" : "Search",
    "All" : "﻿ಎಲ್ಲಾ"
},
"nplurals=2; plural=(n > 1);");
